@@ -5,6 +5,7 @@ module Debian.Relation.Common where
 import Data.List
 import Text.ParserCombinators.Parsec
 import Data.Function
+import Text.PrettyPrint (Doc, text)
 
 -- Local Modules
 
@@ -29,9 +30,9 @@ class ParseRelations a where
     parseRelations :: a -> Either ParseError Relations
 
 
-instance Show Relation where
-    show (Rel name ver arch) =
-        name ++ maybe "" show ver ++ maybe "" show arch
+prettyRelation :: Relation -> Doc
+prettyRelation (Rel name ver arch) =
+    text (name ++ maybe "" (show . prettyVersionReq) ver ++ maybe "" (show . prettyArchitectureReq) arch)
 
 instance Ord Relation where
     compare (Rel pkgName1 mVerReq1 _mArch1) (Rel pkgName2 mVerReq2 _mArch2) =
@@ -45,9 +46,9 @@ data ArchitectureReq
     | ArchExcept [String]
       deriving Eq
 
-instance Show ArchitectureReq where
-    show (ArchOnly arch) = " [" ++ intercalate " " arch ++ "]"
-    show (ArchExcept arch) = " [!" ++ intercalate " !" arch ++ "]"
+prettyArchitectureReq :: ArchitectureReq -> Doc
+prettyArchitectureReq (ArchOnly arch) = text $ " [" ++ intercalate " " arch ++ "]"
+prettyArchitectureReq (ArchExcept arch) = text $ " [!" ++ intercalate " !" arch ++ "]"
 
 data VersionReq
     = SLT DebianVersion
@@ -57,12 +58,12 @@ data VersionReq
     | SGR DebianVersion
       deriving Eq
 
-instance Show VersionReq where
-    show (SLT v) = " (<< " ++ show v ++ ")"
-    show (LTE v) = " (<= " ++ show v ++ ")"
-    show (EEQ v) = " (= " ++ show v ++ ")"
-    show (GRE v) = " (>= " ++ show v ++ ")"
-    show (SGR v) = " (>> " ++ show v ++ ")"
+prettyVersionReq :: VersionReq -> Doc
+prettyVersionReq (SLT v) = text $ " (<< " ++ show (prettyDebianVersion v) ++ ")"
+prettyVersionReq (LTE v) = text $ " (<= " ++ show (prettyDebianVersion v) ++ ")"
+prettyVersionReq (EEQ v) = text $ " (= " ++ show (prettyDebianVersion v) ++ ")"
+prettyVersionReq (GRE v) = text $ " (>= " ++ show (prettyDebianVersion v) ++ ")"
+prettyVersionReq (SGR v) = text $ " (>> " ++ show (prettyDebianVersion v) ++ ")"
 
 -- |The sort order is based on version number first, then on the kind of
 -- relation, sorting in the order <<, <= , ==, >= , >>
