@@ -6,6 +6,7 @@ import Debian.Control  -- (Control(..),lookupP,parseControlFromFile)
 import Debian.Relation
 import System.Process
 import System.Exit
+import System.Environment
 
 lookupBuildDeps :: FilePath -> IO [PkgName]
 lookupBuildDeps fp =
@@ -30,10 +31,14 @@ lookupDepends key paragraph =
       pkgName (Rel name _ _) = name
 
 
-aptGetInstall :: [PkgName] -> IO ExitCode
-aptGetInstall pkgnames = 
-    do (_,_,_,ph) <- createProcess $ proc "apt-get" ("install" : pkgnames)
+aptGetInstall :: [String] -> [PkgName] -> IO ExitCode
+aptGetInstall options pkgnames =
+    do (_,_,_,ph)
+         <- createProcess $ proc "apt-get" $ ["install"] ++ options ++ pkgnames
        waitForProcess ph
        
 main :: IO ()
-main = lookupBuildDeps "debian/control" >>= aptGetInstall >>= exitWith
+main
+  = do
+    options <- getArgs
+    lookupBuildDeps "debian/control" >>= aptGetInstall options >>= exitWith
